=== modified file 'codeigniter/application/models/user.php'
--- codeigniter/application/models/user.php	2013-05-03 11:39:08 +0000
+++ codeigniter/application/models/user.php	2013-05-07 07:47:43 +0000
@@ -6,13 +6,45 @@
 		function __construct() {
 			parent::__construct();
 			
-			//Load required libraries
+			//Load required libraries and drivers
 			$this->load->database();
 			$this->load->library('session');
 		}
 
+
+		/*
+		 *	This function returns the users password hint (or FALSE if user isn't logged in).
+		 *  RESTRICTED-LEVEL: None
+		 */ 
+		public function getPasswordHint($user) {
+			//Query-structure
+			$this->db->select('passwdHint');
+			$this->db->from('Users');
+			$this->db->where('userName', $user);
+			$this->db->limit(1);
+			
+			//Execute query
+			$query = $this->db->get();
+			$result = $query->result();
+			
+			//If a matching DB record is found.
+			if($result) {
+			    foreach($result as $row) {
+			    	$hint = $row->passwdHint;
+			    	
+			    	//Return hint
+			    	return $hint;
+			    }
+			}
+			
+			//No such user
+			return FALSE;
+		}
+
+
 		/*
 		 *	This function logs the user in (returns FALSE on fail).
+		 *  RESTRICTED-LEVEL: None
 		 */ 
 		public function login($username, $password)
 		{			
@@ -57,6 +89,7 @@
 
 		/*
 		 *	This function logs the user out.
+		 *  RESTRICTED-LEVEL: Self
 		 */ 
 		public function logout() {		
 			//Unset session data
@@ -65,103 +98,8 @@
 		
 
 		/*
-		 *	This function return TRUE if the user is logged in and FALSE otherwise.
-		 */ 
-		public function isLoggedIn() {	
-			if ($this->session->userdata('authenticated')) {
-				return TRUE;
-			}
-			
-			return FALSE;
-		}
-		
-		
-		/*
-		 *	This function returns the users type (or FALSE if user isn't logged in).
-		 */ 
-		public function getUserType() {	
-			if($this->isLoggedIn()) {
-				$temp = $this->session->userdata('authenticated');
-				return $temp['usertype'];
-			}
-			
-			return FALSE;
-		}
-		
-		
-		/*
-		 *	This function returns the username (or FALSE if user isn't logged in).
-		 */ 
-		public function getUserName() {	
-			if($this->isLoggedIn()) {
-				$temp = $this->session->userdata('authenticated');
-				return $temp['username'];
-			}
-			
-			return FALSE;
-		}
-		
-		
-		/*
-		 *	This function returns the users password hint (or FALSE if user isn't logged in).
-		 */ 
-		public function getPasswordHint($user) {
-			$hint = '';
-
-			//Query-structure
-			$this->db->select('passwdHint');
-			$this->db->from('Users');
-			$this->db->where('userName', $user);
-			$this->db->limit(1);
-			
-			//Execute query
-			$query = $this->db->get();
-			$result = $query->result();
-			
-			//If a matching DB record is found.
-			if($result) {
-			    foreach($result as $row) {
-			    	$hint = $row->passwdHint;
-			    	return $hint;
-			    }
-			}
-			
-			return FALSE;
-		}
-		
-		
-		/*
-		 *	This function registers user into the database.
-		 */
-		public function addUser($userName, $name, $ssn, $password, $userType, $pwdHint) {
-			//Check that a user is logged in and has the right privileges (is teacher)
-			if($this->isLoggedIn() && $this->getUserType() === 'Teacher') {
-				//Generate a salted hash
-				$hash = $this->getSaltedHash($password);
-				
-				//Query-structure (All values are escaped automatically by codeigninte, producing safer queries.)
-				$this->db->set('userName', $userName);
-				$this->db->set('name', $name);
-				$this->db->set('ssn', $ssn);
-				$this->db->set('passwd', $password);
-				$this->db->set('userType', $userType);
-				$this->db->set('passwdHint', $pwdHint);
-				$result = $this->db->insert('Users');
-				
-				//Check for my-sql error
-				if($result) {
-					//Return success
-					return TRUE;
-				} 
-			}
-			
-			//Return error
-			return FALSE;
-		}
-		
-
-		/*
 		 *	This function changes the users password.
+		 *  RESTRICTED-LEVEL: Self
 		 */ 
 		public function changePassword($pwdOld, $pwdNew, $pwdHint) {
 			//Check that a user is logged in.
@@ -170,7 +108,7 @@
 				$oldHash = $this->getSaltedHash($pwdOld);
 				$newHash = $this->getSaltedHash($pwdNew);
 				
-				//Validate
+				//Validate input with database
 				$this->db->select('userName');
 				$this->db->from('Users');
 				$this->db->where('userName', $user);
@@ -179,7 +117,7 @@
 				$query = $this->db->get();
 				$result = $query->result();
 				
-				//If a matching DB record is found, update database with new info.
+				//If a matching DB record is found, update database.
 				if($result) {
 					$data = array(
 						'passwd' => $newHash,
@@ -198,9 +136,41 @@
 			return FALSE;
 		}
 
+
+		/*
+		 *	This function registers user into the database.
+		 *  RESTRICTED-LEVEL: Teacher
+		 */
+		public function addUser($userName, $name, $ssn, $password, $userType, $pwdHint) {
+			//Check that a user is logged in and has the right privileges (is teacher)
+			if($this->isLoggedIn() && $this->getUserType() === 'Teacher') {
+				//Generate a salted hash
+				$hash = $this->getSaltedHash($password);
+				
+				//Query-structure (All values are escaped automatically by codeigninte, producing safer queries.)
+				$this->db->set('userName', $userName);
+				$this->db->set('name', $name);
+				$this->db->set('ssn', $ssn);
+				$this->db->set('passwd', $password);
+				$this->db->set('userType', $userType);
+				$this->db->set('passwdHint', $pwdHint);
+				$result = $this->db->insert('Users');
+				
+				//Check for my-sql error
+				if($result) {
+					//Return success
+					return TRUE;
+				} 
+			}
+			
+			//Return error
+			return FALSE;
+		}
+		
 		
 		/*
 		 *	This function removes users from the database.
+		 *  RESTRICTED-LEVEL: Teacher
 		 */ 
 		public function removeUser($userName) {
 			//Check that a user is logged in, has the right privileges (is teacher) and not is the users own username.
@@ -222,27 +192,57 @@
 		
 
 		/*
-		 *	Generates a password hash using a user-unique salt.
+		 *	Generates a salted password hash, encrypted with sha1.
 		 */		
-		private function getSaltedHash($pwd)
-		{	
-			/* Salt algorithm:
-			 * Step 1: Get encryption key
-			 * Step 2: Salt is set to password (reversed)
-			 * Step 3: Salt is encrypted with MD5
-			 * Step 4: Salt is reversed (again)
-			 * Step 5: Salt is encrypted with SHA1
-			 */
-			
-			$salt = '';
-			
-			//UNCOMMENT TO ACTIVATE SALT LATER IN DEVELOPMENT!!!
-			//$salt = sha1(strrev(md5(strrev($this->config->item('encryption_key')))));
+		private function getSaltedHash($pwd) {
+			//Salt = CodeIgniters encryption-key from config
+			$salt = $this->config->item('encryption_key');
 			
 			//Generate SHA1 hash using salt
 			$hash = sha1($salt.$pwd);
 			
 			return $hash;
 		}
+		
+		
+		/*
+		 *	This function return TRUE if the user is logged in and FALSE otherwise.
+		 *  RESTRICTED-LEVEL: System
+		 */ 
+		public function isLoggedIn() {	
+			if ($this->session->userdata('authenticated')) {
+				return TRUE;
+			}
+			
+			return FALSE;
+		}
+		
+		
+		/*
+		 *	This function returns the users type (or FALSE if user isn't logged in).
+		 *  RESTRICTED-LEVEL: System
+		 */ 
+		public function getUserType() {	
+			if($this->isLoggedIn()) {
+				$temp = $this->session->userdata('authenticated');
+				return $temp['usertype'];
+			}
+			
+			return FALSE;
+		}
+		
+		
+		/*
+		 *	This function returns the username (or FALSE if user isn't logged in).
+		 *  RESTRICTED-LEVEL: System
+		 */ 
+		public function getUserName() {	
+			if($this->isLoggedIn()) {
+				$temp = $this->session->userdata('authenticated');
+				return $temp['username'];
+			}
+			
+			return FALSE;
+		}
 	}
 ?>
\ No newline at end of file

